*------------------------------------------------------------*;
* Neural: Create decision matrix;
*------------------------------------------------------------*;
data WORK.Churn2;
  length   Churn2                           $  32
           COUNT                                8
           DATAPRIOR                            8
           TRAINPRIOR                           8
           DECPRIOR                             8
           DECISION1                            8
           DECISION2                            8
           ;

  label    COUNT="Level Counts"
           DATAPRIOR="Data Proportions"
           TRAINPRIOR="Training Proportions"
           DECPRIOR="Decision Priors"
           DECISION1="1"
           DECISION2="0"
           ;
Churn2="1"; COUNT=1004; DATAPRIOR=0.05868942538142; TRAINPRIOR=5.86894253814228; DECPRIOR=.; DECISION1=1; DECISION2=0;
output;
Churn2="0"; COUNT=16103; DATAPRIOR=0.94131057461857; TRAINPRIOR=94.1310574618577; DECPRIOR=.; DECISION1=0; DECISION2=1;
output;
;
run;
proc datasets lib=work nolist;
modify Churn2(type=PROFIT label=Churn2);
label DECISION1= "1";
label DECISION2= "0";
run;
quit;
*------------------------------------------------------------* ;
* Neural: DMDBClass Macro ;
*------------------------------------------------------------* ;
%macro DMDBClass;
    Churn2(DESC) GRP_IMP_Age(ASC) GRP_OffPeak_calls_ratio(ASC)
   GRP_OffPeak_calls_ratio_out(ASC) GRP_OffPeak_mins_ratio(ASC)
   GRP_OffPeak_mins_ratio_out(ASC) GRP_Peak_calls_1234(ASC) GRP_Peak_calls_56(ASC)
   GRP_Peak_mins_ratio(ASC) GRP_Peak_mins_ratio_out(ASC) GRP_mon_dif(ASC)
   GRP_tariff(ASC)
%mend DMDBClass;
*------------------------------------------------------------* ;
* Neural: DMDBVar Macro ;
*------------------------------------------------------------* ;
%macro DMDBVar;

%mend DMDBVar;
*------------------------------------------------------------*;
* Neural: Create DMDB;
*------------------------------------------------------------*;
proc dmdb batch data=EMWS.Drop2_TRAIN dmdbcat=WORK.Neural_DMDB
maxlevel = 513
;
class %DMDBClass;
target
Churn2
;
run;
quit;
*------------------------------------------------------------* ;
* Neural: Interval Input Variables Macro ;
*------------------------------------------------------------* ;
%macro INTINPUTS;

%mend INTINPUTS;
*------------------------------------------------------------* ;
* Neural: Binary Inputs Macro ;
*------------------------------------------------------------* ;
%macro BININPUTS;

%mend BININPUTS;
*------------------------------------------------------------* ;
* Neural: Nominal Inputs Macro ;
*------------------------------------------------------------* ;
%macro NOMINPUTS;

%mend NOMINPUTS;
*------------------------------------------------------------* ;
* Neural: Ordinal Inputs Macro ;
*------------------------------------------------------------* ;
%macro ORDINPUTS;
    GRP_IMP_Age GRP_OffPeak_calls_ratio GRP_OffPeak_calls_ratio_out
   GRP_OffPeak_mins_ratio GRP_OffPeak_mins_ratio_out GRP_Peak_calls_1234
   GRP_Peak_calls_56 GRP_Peak_mins_ratio GRP_Peak_mins_ratio_out GRP_mon_dif
   GRP_tariff
%mend ORDINPUTS;
*------------------------------------------------------------*;
* Neural Network Training;
;
*------------------------------------------------------------*;
proc neural data=EMWS.Drop2_TRAIN dmdbcat=WORK.Neural_DMDB
validdata = EMWS.Drop2_VALIDATE
random=12345
;
netopts
decay=0;
input %ORDINPUTS / level=ordinal id=ord
;
target Churn2 / level=NOMINAL id=Churn2
bias
;
arch MLP
Hidden=3
;
nloptions
;
Prelim 5 preiter=10
pretime=3600
Outest=EMWS.Neural_PRELIM_OUTEST
;
save network=EMWS.Neural_NETWORK.dm_neural;
train Maxiter=50
maxtime=14400
Outest=EMWS.Neural_outest estiter=1
Outfit=EMWS.Neural_OUTFIT
;
run;
quit;
proc sort data=EMWS.Neural_OUTFIT(where=(_iter_ ne . and _NAME_="OVERALL")) out=fit_Neural;
by _VAVERR_;
run;
%GLOBAL ITER;
data _null_;
set fit_Neural(obs=1);
call symput('ITER',put(_ITER_, 6.));
run;
data EMWS.Neural_INITIAL;
set EMWS.Neural_outest(where=(_ITER_ eq &ITER and _OBJ_ ne .));
run;
*------------------------------------------------------------*;
* Neural Network Model Selection;
;
*------------------------------------------------------------*;
proc neural data=EMWS.Drop2_TRAIN dmdbcat=WORK.Neural_DMDB
validdata = EMWS.Drop2_VALIDATE
network = EMWS.Neural_NETWORK.dm_neural
random=12345
;
initial inest=EMWS.Neural_INITIAL;
train tech=NONE;
nloptions noprint;
code file="D:\EM\churn\Workspaces\EMWS\Neural\SCORECODE.sas"
group=Neural
;
;
code file="D:\EM\churn\Workspaces\EMWS\Neural\RESIDUALSCORECODE.sas"
group=Neural
residual
;
;
score data=EMWS.Drop2_TRAIN out=_NULL_
outfit=WORK.FIT1
role=TRAIN
outkey=EMWS.Neural_OUTKEY;
score data=EMWS.Drop2_VALIDATE out=_NULL_
outfit=WORK.FIT2
role=VALID
outkey=EMWS.Neural_OUTKEY;
score data=EMWS.Drop2_TEST out=_NULL_
outfit=WORK.FIT3
role=TEST
outkey=EMWS.Neural_OUTKEY;
run;
quit;
data EMWS.Neural_OUTFIT;
merge WORK.FIT1 WORK.FIT2 WORK.FIT3;
run;
data EMWS.Neural_EMESTIMATE;
set EMWS.Neural_outest;
if _type_ ^in('HESSIAN' 'GRAD');
run;
