*------------------------------------------------------------*;
* Tree: Create decision matrix;
*------------------------------------------------------------*;
data WORK.Churn2;
  length   Churn2                           $  32
           COUNT                                8
           DATAPRIOR                            8
           TRAINPRIOR                           8
           DECPRIOR                             8
           DECISION1                            8
           DECISION2                            8
           ;

  label    COUNT="Level Counts"
           DATAPRIOR="Data Proportions"
           TRAINPRIOR="Training Proportions"
           DECPRIOR="Decision Priors"
           DECISION1="1"
           DECISION2="0"
           ;
Churn2="1"; COUNT=1004; DATAPRIOR=0.05868942538142; TRAINPRIOR=5.86894253814228; DECPRIOR=.; DECISION1=1; DECISION2=0;
output;
Churn2="0"; COUNT=16103; DATAPRIOR=0.94131057461857; TRAINPRIOR=94.1310574618577; DECPRIOR=.; DECISION1=0; DECISION2=1;
output;
;
run;
proc datasets lib=work nolist;
modify Churn2(type=PROFIT label=Churn2);
label DECISION1= "1";
label DECISION2= "0";
run;
quit;
*------------------------------------------------------------* ;
* Tree: DMDBClass Macro ;
*------------------------------------------------------------* ;
%macro DMDBClass;
    Churn2(DESC) GRP_IMP_Age(ASC) GRP_OffPeak_calls_ratio(ASC)
   GRP_OffPeak_calls_ratio_out(ASC) GRP_OffPeak_mins_ratio(ASC)
   GRP_OffPeak_mins_ratio_out(ASC) GRP_Peak_calls_1234(ASC) GRP_Peak_calls_56(ASC)
   GRP_Peak_mins_ratio(ASC) GRP_Peak_mins_ratio_out(ASC) GRP_mon_dif(ASC)
   GRP_tariff(ASC)
%mend DMDBClass;
*------------------------------------------------------------* ;
* Tree: DMDBVar Macro ;
*------------------------------------------------------------* ;
%macro DMDBVar;

%mend DMDBVar;
*------------------------------------------------------------*;
* Tree: Create DMDB;
*------------------------------------------------------------*;
proc dmdb batch data=EMWS.Drop2_TRAIN dmdbcat=WORK.Tree_DMDB
maxlevel = 513
;
class %DMDBClass;
target
Churn2
;
run;
quit;
*------------------------------------------------------------* ;
* Tree: Interval Inputs Macro ;
*------------------------------------------------------------* ;
%macro INTINPUTS;

%mend INTINPUTS;
*------------------------------------------------------------* ;
* Tree: Binary and Nominal Inputs Macro ;
*------------------------------------------------------------* ;
%macro NOMINPUTS;

%mend NOMINPUTS;
*------------------------------------------------------------* ;
* Tree: Ordinal Inputs Macro ;
*------------------------------------------------------------* ;
%macro ORDINPUTS;
    GRP_IMP_Age GRP_OffPeak_calls_ratio GRP_OffPeak_calls_ratio_out
   GRP_OffPeak_mins_ratio GRP_OffPeak_mins_ratio_out GRP_Peak_calls_1234
   GRP_Peak_calls_56 GRP_Peak_mins_ratio GRP_Peak_mins_ratio_out GRP_mon_dif
   GRP_tariff
%mend ORDINPUTS;
*------------------------------------------------------------*;
* Tree: Run ARBOR procedure;
*------------------------------------------------------------*;
proc arbor data=EMWS.Drop2_TRAIN
Leafsize=5
Mincatsize = 5
Maxbranch=2
Maxdepth=6
alpha = 0.2
Padjust=
CHAIDBEFORE
DEPTH
MAXRULES=5
MAXSURRS=0
Missing=USEINSEARCH
Exhaustive=5000
event='1'
;
input %ORDINPUTS
/ level=ordinal;
target Churn2 / level=BINARY
Criterion=PROBCHISQ
;
;
Performance DISK
NodeSize=20000
;
Assess
Validata=EMWS.Drop2_VALIDATE
measure=MISC
;
SUBTREE BEST
;
MAKEMACRO NLEAVES=nleaves;
save
MODEL=EMWS.Tree_EMTREE
SEQUENCE=EMWS.Tree_OUTSEQ
IMPORTANCE=EMWS.Tree_OUTIMPORT
NODESTAT=EMWS.Tree_OUTNODES
SUMMARY=EMWS.Tree_OUTSUMMARY
STATSBYNODE=EMWS.Tree_OUTSTATS
Topology=EMWS.Tree_OUTTOPOLOGY
Path = EMWS.Tree_OUTPATH
;
DESCRIBE File=X;
code file="D:\EM\churn\Workspaces\EMWS\Tree\EMPUBLISHSCORE.sas"
group=Tree
;
code file="D:\EM\churn\Workspaces\EMWS\Tree\EMFLOWSCORE.sas"
group=Tree
residual
;
score data=EMWS.Drop2_TRAIN out=_NULL_
outfit=WORK.FIT1
role=TRAIN
;
score data=EMWS.Drop2_VALIDATE out=_NULL_
outfit=WORK.FIT2
role=VALID
;
score data=EMWS.Drop2_TEST out=_NULL_
outfit=WORK.FIT3
role=TEST
;
run;
quit;
%put &nleaves;
data EMWS.Tree_OUTFIT;
merge WORK.FIT1 WORK.FIT2 WORK.FIT3;
run;
data EMWS.Tree_OUTIMPORT;
set EMWS.Tree_OUTIMPORT;
label NAME = "%sysfunc(sasmsg(sashelp.dmine, meta_name_vlabel, noquote))" LABEL = "%sysfunc(sasmsg(sashelp.dmine, meta_label_vlabel, noquote))" NRULES = "%sysfunc(sasmsg(sashelp.dmine, rpt_nrules_vlabel, noquote))" IMPORTANCE =
   "%sysfunc(sasmsg(sashelp.dmine, rpt_importance_vlabel, noquote))" NSURROGATES = "%sysfunc(sasmsg(sashelp.dmine, rpt_nsurrogates_vlabel, noquote))"
VIMPORTANCE = "%sysfunc(sasmsg(sashelp.dmine, rpt_vimportance_vlabel, noquote))" RATIO = "%sysfunc(sasmsg(sashelp.dmine, rpt_ratio_vlabel, noquote))"
;
run;
